You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by gb...@apache.org on 2022/04/20 16:49:15 UTC

svn commit: r1900077 - in /httpd/httpd/trunk: docs/manual/mod/mod_authz_dbd.xml modules/aaa/mod_authz_dbd.c

Author: gbechis
Date: Wed Apr 20 16:49:15 2022
New Revision: 1900077

URL: http://svn.apache.org/viewvc?rev=1900077&view=rev
Log:
fix select-groups example, bz 66010

Modified:
    httpd/httpd/trunk/docs/manual/mod/mod_authz_dbd.xml
    httpd/httpd/trunk/modules/aaa/mod_authz_dbd.c

Modified: httpd/httpd/trunk/docs/manual/mod/mod_authz_dbd.xml
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/docs/manual/mod/mod_authz_dbd.xml?rev=1900077&r1=1900076&r2=1900077&view=diff
==============================================================================
--- httpd/httpd/trunk/docs/manual/mod/mod_authz_dbd.xml (original)
+++ httpd/httpd/trunk/docs/manual/mod/mod_authz_dbd.xml Wed Apr 20 16:49:15 2022
@@ -70,7 +70,7 @@
 
     <highlight language="config">
 Require dbd-group team
-AuthzDBDQuery "SELECT group FROM authz WHERE user = %s"
+AuthzDBDQuery "SELECT user_group FROM authz WHERE user = %s"
     </highlight>
 
 </section>

Modified: httpd/httpd/trunk/modules/aaa/mod_authz_dbd.c
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/modules/aaa/mod_authz_dbd.c?rev=1900077&r1=1900076&r2=1900077&view=diff
==============================================================================
--- httpd/httpd/trunk/modules/aaa/mod_authz_dbd.c (original)
+++ httpd/httpd/trunk/modules/aaa/mod_authz_dbd.c Wed Apr 20 16:49:15 2022
@@ -212,7 +212,7 @@ static int authz_dbd_login(request_rec *
 static int authz_dbd_group_query(request_rec *r, authz_dbd_cfg *cfg,
                                  apr_array_header_t *groups)
 {
     /* SELECT group FROM authz WHERE user = %s */
     int rv;
     const char *message;
     ap_dbd_t *dbd;
@@ -254,7 +254,7 @@ static int authz_dbd_group_query(request
             else {
                 message = apr_dbd_error(dbd->driver, dbd->handle, rv);
                 ap_log_rerror(APLOG_MARK, APLOG_ERR, 0, r, APLOGNO(01651)
-                        "authz_dbd in get_row; group query for user=%s [%s]",
+                        "authz_dbd in get_row; user_group query for user=%s [%s]",
                         r->user, message?message:noerror);
                 return HTTP_INTERNAL_SERVER_ERROR;
             }
@@ -212,7 +212,7 @@ static int authz_dbd_login(request_rec *
                                  apr_array_header_t *groups)
 {
-    /* SELECT group FROM authz WHERE user = %s */
+    /* SELECT user_group FROM authz WHERE user = %s */
     int rv;
     const char *message;